Welcome to ClientVPS Mirrors

Help for package UEI
Type: Package
Title: Compute Uniform Error Index
Version: 0.1.0
Author: Mr. Ankit Kumar Singh [aut], Dr. Ranjit Kumar Paul [aut, cre], Dr. Md Yeasin [aut], Ms. Anita Sarkar [aut], Dr. Amrit Kumar Paul [aut]
Maintainer: Dr. Ranjit Kumar Paul <ranjitstat@gmail.com>
Description: Uniform Error Index is the weighted average of different error measures. Uniform Error Index utilizes output from different error function and gives more robust and stable error values. This package has been developed to compute Uniform Error Index from ten different loss function like Error Square, Square of Square Error, Quasi Likelihood Error, LogR-Square, Absolute Error, Absolute Square Error etc. The weights are determined using Principal Component Analysis (PCA) algorithm of Yeasin and Paul (2024) <doi:10.1007/s11227-023-05542-3>.
License: GPL-3
Encoding: UTF-8
Imports: FactoMineR, factoextra, Metrics
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2024-07-29 11:26:02 UTC; HP
Repository: CRAN
Date/Publication: 2024-07-31 10:00:01 UTC

Uniform Error Index

Description

Uniform Error Index

Usage

UEI(actual, predicted)

Arguments

actual

Univariate Data Series

predicted

Predicted Data Series from Models

Value

References

Examples

library("UEI")
actual<- as.ts(rnorm(50,100,50))
predicted<- as.ts(rnorm(50,110,60))
Result <- UEI(actual, predicted)

Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.